@@ -124,20 +124,32 @@ function user_new_curse(num)
 
     if num<10 then
         num=ID_CURSE_ANTIDOTE
-    elseif num<70 then
+    elseif num<20 then
         num=ID_CURSE_HOLEDLINE
-    elseif num<75 then
+    elseif num<30 then
         num=ID_CURSE_GOOFY
-    elseif num<80 then
+    elseif num<40 then
         num=ID_CURSE_CLEAR
-    elseif num<85 then 
+    elseif num<50 then 
+        num=ID_CURSE_DROP
+    elseif num<60 then 
+        num=ID_CURSE_STAIRS
+    elseif num<65 then 
+        num=ID_CURSE_BOOST
+    elseif num<70 then 
         num=ID_CURSE_SHUFFLE
-    elseif num<90 then 
+    elseif num<75 then 
         num=ID_CURSE_WIND
-    elseif num<95 then 
+    elseif num<80 then 
         num=ID_CURSE_FIFTYTWO
-    elseif num<100 then 
+    elseif num<85 then 
         num=ID_CURSE_BIGX
+    elseif num<90 then 
+        num=ID_CURSE_TOPHOLEDLINE
+    elseif num<95 then 
+        num=ID_CURSE_TOPDOWN
+    elseif num<100 then 
+        num=ID_CURSE_HAHA
     end
 
     return num
@@ -160,6 +172,18 @@ function user_do_curse(num,sent)
         fiftytwo_do_curse(sent)
     elseif (num==ID_CURSE_BIGX) then
         bigx_do_curse(sent)
+    elseif (num==ID_CURSE_BOOST) then
+        boost_do_curse(sent)
+    elseif (num==ID_CURSE_DROP) then
+        drop_do_curse(sent)
+    elseif (num==ID_CURSE_TOPDOWN) then
+        topdown_do_curse(sent)
+    elseif (num==ID_CURSE_TOPHOLEDLINE) then
+        topholedline_do_curse(sent)
+    elseif (num==ID_CURSE_STAIRS) then
+        stairs_do_curse(sent)
+    elseif (num==ID_CURSE_HAHA) then
+        haha_do_curse(sent)
     end    
 end
 
@@ -182,6 +206,18 @@ function user_get_curse_name(num)
         name="52"
     elseif (num==ID_CURSE_BIGX) then
         name="X"
+    elseif (num==ID_CURSE_BOOST) then
+        name="boost"
+    elseif (num==ID_CURSE_DROP) then
+        name="drop"
+    elseif (num==ID_CURSE_TOPDOWN) then
+        name="topdown"
+    elseif (num==ID_CURSE_TOPHOLEDLINE) then
+        name="toper"
+    elseif (num==ID_CURSE_STAIRS) then
+        name="stairs"
+    elseif (num==ID_CURSE_HAHA) then
+        name="haha"
     end
 
     return name
@@ -193,9 +229,11 @@ function user_time_callback()
     u61_add_score(10)
     shuffle_time_callback()
     wind_time_callback()
+    boost_time_callback()
 end
 
 
+
 -- various functions used for pattern matching -------------------------------
 
 function utils_shift_column_down(x_col,y_bottom)
@@ -259,6 +297,46 @@ function utils_clear_map()
         y=y+1
     end
 end
+
+function utils_switch_lines(y1,y2)
+    local x
+    local color
+
+    x=u61_get_width()-1
+    while x>=0 do
+        color=u61_get_square_color(x,y1)
+        u61_set_square_color(x,y1,u61_get_square_color(x,y2))
+        u61_set_square_color(x,y2,color)
+        x=x-1
+    end
+end
+
+function utils_get_highest_square_y()
+    local x
+    local y
+    local width
+    local height
+    local min_y	
+
+    width=u61_get_width()
+    height=u61_get_height()
+    min_y=height 
+    y=0
+    while y<height do
+        x=0
+        while x<width do
+            if u61_get_square_color(x,y)>=0 then
+                min_y=y
+                x=width
+                y=height
+            end
+            x=x+1
+        end
+        y=y+1
+    end 
+
+    return min_y   
+end
 -- defines tetraminos --------------------------------------------------------
 
 function tetramino_bar()
@@ -322,6 +400,50 @@ function translation_y(y)
     u61_set_block_y(u61_get_block_y()+y)
 end
 
+function translation_x_check(x)
+    local i
+    local dx
+	
+    if x>0 then
+        dx=1
+    else
+        x=-x
+        dx=-1
+    end
+
+    i=x
+    while i>0 do
+        translation_x(dx)
+        if u61_is_block_ok()==0 then
+            translation_x(-dx)
+            i=0
+        end
+        i=i-1	          
+    end
+end
+
+function translation_y_check(y)
+    local i
+    local dy
+	
+    if y>0 then
+        dy=1
+    else
+        y=-y
+        dy=-1
+    end
+
+    i=y
+    while i>0 do
+        translation_y(dy)
+        if u61_is_block_ok()==0 then
+            translation_y(-dy)
+            i=0
+        end
+        i=i-1		          
+    end
+end
+
 
 -- defines geometrical rotations ---------------------------------------------
 
@@ -625,3 +747,193 @@ function bigx_do_curse(sent)
     end
 end
 
+
+-- BOOST curse: makes the blocks fall very fast for a few seconds ------------
+
+ID_CURSE_BOOST=10
+
+function boost_do_curse(sent)
+    if sent==0 then
+        u61_send_curse(ID_CURSE_BOOST)
+    else
+        u61_register_curse(ID_CURSE_BOOST,5)
+    end
+end
+
+function boost_time_callback()
+    if u61_get_curse_age(ID_CURSE_BOOST)>=0 then
+        translation_y(1)
+    end
+end
+
+
+-- DROP curse: forces the block of the opponent to be dropped --- ------------
+
+ID_CURSE_DROP=11
+
+function drop_do_curse(sent)
+    if sent==0 then
+        u61_send_curse(ID_CURSE_DROP)
+    else
+        translation_y_check(u61_get_height())
+    end
+end
+
+
+-- TOPDOWN curse: inverts the map, squares at the bottom go to the top -------
+
+ID_CURSE_TOPDOWN=12
+
+function topdown_do_curse(sent)
+    local height
+    local y
+    local min_y
+
+    if sent==0 then
+        u61_send_curse(ID_CURSE_TOPDOWN)
+    else
+        min_y=utils_get_highest_square_y()
+        height=u61_get_height()
+        y=floor((height-min_y)/2)-1
+        while y>=0 do
+            utils_switch_lines(height-1-y,min_y+y)
+            y=y-1
+        end        
+    end
+end
+
+
+
+-- TOPHOLEDLINE curse: puts 2 lines with a hole on top of the map ------------
+
+ID_CURSE_TOPHOLEDLINE=13
+
+function topholedline_do_curse(sent)
+    local x
+    local y
+    local width
+    local color1
+    local color2
+
+    if sent==0 then
+        u61_send_curse(ID_CURSE_TOPHOLEDLINE)
+    else
+        width=u61_get_width()
+        y=utils_get_highest_square_y()
+
+        x=0
+        while x<width do
+            if (mod(x+u61_get_time(),width)==0) then
+                color1=-1
+            else
+               color1=7
+            end
+
+            if (mod(x+u61_get_time(),width)==floor(width/2)) then
+                color2=-1
+            else
+               color2=7
+            end
+
+            u61_set_square_color(x,y-1,color1)
+            u61_set_square_color(x,y-2,color2)
+            x=x+1
+        end
+    end
+end
+
+
+
+-- STAIRS curse, draws stairs on the map -------------------------------------
+
+ID_CURSE_STAIRS=14
+
+function stairs_do_curse(sent)
+    if sent==0 then
+        u61_send_curse(ID_CURSE_STAIRS)
+    else
+        if (mod(u61_get_time(),2)==0) then
+            stairs_right()
+        else
+            stairs_left()
+        end
+    end
+end
+
+function stairs_right()
+    local x
+    local y
+    local height
+
+    height=u61_get_height()
+    x=u61_get_width()-1
+    while x>=0 do
+        y=height-1-x
+        u61_set_square_color(x-1,y,-1)
+        u61_set_square_color(x,y,7)
+        u61_set_square_color(x+1,y,-1)
+        x=x-1
+    end
+end
+
+function stairs_left()
+    local x
+    local y
+    local height
+    local width
+
+    width=u61_get_width()
+    height=u61_get_height()
+    x=width
+    while x>0 do
+        y=height-x
+        u61_set_square_color(width-x-1,y,-1)
+        u61_set_square_color(width-x,y,7)
+        u61_set_square_color(width-x+1,y,-1)
+        x=x-1
+    end
+end
+
+-- HAHA curse, writes "HA HA" on the map -------------------------------------
+
+ID_CURSE_HAHA=15
+
+function haha_do_curse(sent)
+    if sent==0 then
+        u61_send_curse(ID_CURSE_HAHA)
+    else
+        utils_clear_map()
+        haha_draw_h(1,12)
+        haha_draw_a(5,12)
+        haha_draw_h(2,18)
+        haha_draw_a(6,18)
+    end
+end
+
+function haha_draw_h(x,y)
+    u61_set_square_color(x+0,y+0,7)
+    u61_set_square_color(x+0,y+1,7)
+    u61_set_square_color(x+0,y+2,7)
+    u61_set_square_color(x+0,y+3,7)
+    u61_set_square_color(x+0,y+4,7)
+    u61_set_square_color(x+1,y+2,7)
+    u61_set_square_color(x+2,y+0,7)
+    u61_set_square_color(x+2,y+1,7)
+    u61_set_square_color(x+2,y+2,7)
+    u61_set_square_color(x+2,y+3,7)
+    u61_set_square_color(x+2,y+4,7)
+end
+
+function haha_draw_a(x,y)
+    u61_set_square_color(x+0,y+1,7)
+    u61_set_square_color(x+0,y+2,7)
+    u61_set_square_color(x+0,y+3,7)
+    u61_set_square_color(x+0,y+4,7)
+    u61_set_square_color(x+1,y+0,7)
+    u61_set_square_color(x+1,y+2,7)
+    u61_set_square_color(x+2,y+1,7)
+    u61_set_square_color(x+2,y+2,7)
+    u61_set_square_color(x+2,y+3,7)
+    u61_set_square_color(x+2,y+4,7)
+end
+
