@@ -63,7 +63,7 @@ class U61_ClientProtocol : public U61_Protocol
   virtual int recv_next_packet();
 
  protected:
-  static const int JOIN_DELAY=100;
+  static const unsigned int JOIN_DELAY=100;
   
   char *server_id;
   U61_ClientDispatcher *dispatcher;
@@ -74,7 +74,7 @@ class U61_ClientProtocol : public U61_Protocol
   int acceleration;
   int curse_delay;
   int time;
-  int join_delay_start;
+  unsigned int join_delay_start;
   int channel_to_test;
 
   const static int SEARCHING=10;
