@@ -48,6 +48,8 @@
 #include "platform.h"
 #include "script.h"
 #include "debug.h"
+#include "sound.h"
+#include "music.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -129,8 +131,8 @@ void U61_Config::reset()
   acceleration=read_int(ID_ACCELERATION,5);
   curse_delay=read_int(ID_CURSE_DELAY,20);
 
-  sound_volume=read_int(ID_SOUND_VOLUME,10);
-  music_volume=read_int(ID_MUSIC_VOLUME,10);
+  sound_volume=read_int(ID_SOUND_VOLUME,U61_Sound::VOLUME_MAX/2);
+  music_volume=read_int(ID_MUSIC_VOLUME,U61_Music::VOLUME_MAX/2);
 
   max_fps=read_int(ID_MAX_FPS,18);
 
