@@ -396,9 +396,14 @@ bool U61_Data::load_sounds()
 bool U61_Data::load_musics()
 {
   bool success=true;
+  /*  int i;
 
-  //    mikmod_test=CL_Streamed_MikModSample::create("data/music/country.mod",NULL,true);
-  //    success=success && (mikmod_test!=NULL);
+  nb_music=2;
+  for (i=0;i<nb_music && success;++i)
+    {
+      music[i]=CL_Streamed_MikModSample::create("/home/ufoot/data/mod/FAIRLI.MOD",NULL,true);
+      success=success && (music[i]!=NULL);
+      }*/
    
   return success;
 }
