@@ -64,6 +64,7 @@ public:
     static const int SIZE_BIG=0;
     static const int SIZE_SMALL=1;
     static const int NB_MAP_MAX=128;
+    static const int NB_MUSIC_MAX=1024;
 
     int screen_w;
     int screen_h;
@@ -93,6 +94,7 @@ public:
     int offset_next_curse_y[NB_SIZE];
    
     int nb_map;
+    int nb_music;
 
     CL_Font *font_menu;
     CL_Font *font_info[NB_SIZE];
@@ -107,7 +109,7 @@ public:
     CL_SoundBuffer *sound_curse_receive;
     CL_SoundBuffer *sound_player_loose;
  
-    CL_SoundBuffer *mikmod_test;
+    CL_SoundBuffer *music[NB_MUSIC_MAX];
  
     CL_Surface *square[NB_SQUARE_TYPE][NB_SIZE];
     CL_Surface *curse[NB_SIZE];
@@ -211,6 +213,9 @@ protected:
     static char *const ID_SOUND_CURSE_RECEIVE="sound/curse_receive";
     static char *const ID_SOUND_PLAYER_LOOSE="sound/player_loose";
  
+    static char *const ID_MUSIC_MOD="music/mod_";
+    static char *const ID_MUSIC_NUMBER="music/number";
+
     static char *const ID_SQUARE_BIG="square/big_n";
     static char *const ID_SQUARE_SMALL="square/small_n";
     static char *const ID_SQUARE_CURSE="curse";
