@@ -188,7 +188,7 @@ bool U61_Dispatcher::process()
 	    {
                busy_flag[event.target]=true;
 	    }
-	  if ((signed int) event.time>U61_Time::for_event())
+	  if (event.time>U61_Time::for_event())
 	    {
 	      U61_LOG_DEBUG("Speeding up");
 	      U61_Time::speed_up();
@@ -197,6 +197,11 @@ bool U61_Dispatcher::process()
 	}
       count++;
     }
+ 
+  if (count>MAX_AT_ONCE/2)
+    {
+      U61_LOG_WARNING("Dispatcher is filled up with events");
+    }
 
   while (!empty_out())
     {
