@@ -86,6 +86,9 @@ class U61_Event
   unsigned int target : 4;
   unsigned int par : 16;
   unsigned int time : 32;
+
+  void serialize(unsigned char *buffer);
+  void unserialize(unsigned char *buffer);
   
  protected:  
 };
