@@ -55,7 +55,7 @@
  * creation of the exit menu
  */ 
 U61_ExitMenu::U61_ExitMenu() 
-    : U61_Menu(NULL,"Are you sure you want to quit U61?")
+    : U61_Menu(NULL,"Are you sure?")
 {
     add_item(new U61_Button("Exit"));
     add_item(new U61_Button("Back to U61"));
