@@ -108,8 +108,10 @@ bool U61_FileMenu::add_files(char *dir)
   char *name;
   char buffer_label[U61_STRING_SIZE];
   char buffer_name[U61_STRING_SIZE];
+  char last_chosen_file[U61_STRING_SIZE];
   bool exists=false;
 
+  strcpy(last_chosen_file,chosen_file);
   U61_LOG_DEBUG("Searching "<<dir<<" for \""<<extension<<"\" files.");
   if (U61_Platform::open_dir(dir,extension))
     {
@@ -122,7 +124,7 @@ bool U61_FileMenu::add_files(char *dir)
 	      
 	  add_item(new U61_File(buffer_label,buffer_name,chosen_file));
 
-          if (strcmp(buffer_name,chosen_file)==0)
+          if (strcmp(buffer_name,last_chosen_file)==0)
 	    {
               last_selection=last_added;
 	    }
@@ -131,6 +133,7 @@ bool U61_FileMenu::add_files(char *dir)
         }
       U61_Platform::close_dir();
     }
+  strcpy(chosen_file,last_chosen_file);
 
   return exists;
 }
