@@ -169,9 +169,12 @@ void U61_Game::deinit()
 void U61_Game::run()
 {
   int done_for_this_display;
+  bool last_display_too_slow;
   U61_Menu *exit_menu;
 
   state=STATE_RUN;
+  slow_down_allowed=true;
+  last_display_too_slow=false;
     
   bind_keys();
   reset_players();
@@ -202,7 +205,6 @@ void U61_Game::run()
    * Plays a startup sound
    */
   U61_Sound::play_game_start();
-  U61_Music::test();
 
   /*
    * main game loop
@@ -226,18 +228,36 @@ void U61_Game::run()
         }
 
       /*
-       * if "max_logic_per_display" calls to logic have been
+       * if "max_logic_per_display/2" calls to logic have been
        * done, it means the computer is slow, therefore, we
        * force the computer to slow down the game, since it's
        * not powerfull enough to run it at full speed
        */
-      if (done_for_this_display>=MAX_LOGIC_PER_DISPLAY)
+      if (done_for_this_display>LIMIT_LOGIC_PER_DISPLAY)
         {
-          /*  while (U61_Time::is_logic_needed())
-	      {
-	      U61_Time::slow_down();
-	      }*/
+	  /*
+	   * We display a warning message if display is slow twice in a row
+	   * This avoids a useless warning when the game starts for instance,
+	   * or the player switches between console and graphic modes
+	   */
+	  if (last_display_too_slow)
+	    {
+	      U61_LOG_WARNING("Display is too slow");
+	    }
+	  last_display_too_slow=true;
+	  
+	  if (slow_down_allowed)
+	    {
+	      while (U61_Time::is_logic_needed())
+		{
+		  U61_Time::slow_down();
+		}
+	    }
         }
+      else
+	{
+	  last_display_too_slow=false;
+	}
 
       /*
        * call the display, menu and flip fonctions once per loop
@@ -387,6 +407,13 @@ void U61_Game::display()
    */
   U61_Global::input_monitor.check();
 
+  /*
+   * This call is necessary for the music module to work correctly,
+   * for instance it will update the volume and handle the end of
+   * a song.
+   */
+  U61_Music::update();
+
   calls_to_display++;  
 }
 
@@ -549,6 +576,8 @@ void U61_Game::start_local_alone()
   U61_LOG_DEBUG("local alone game started");
   if (standard_init())
     {
+      slow_down_allowed=true;
+
       dispatcher=new U61_LocalDispatcher();
 
       num=get_local_player(0);
@@ -559,6 +588,8 @@ void U61_Game::start_local_alone()
 			   &(U61_Global::config.player[num]));
       U61_Global::layout.init_alone(&(player[0]));
     }
+
+  U61_Music::start();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -571,6 +602,8 @@ void U61_Game::start_local_multiplayer()
   U61_LOG_DEBUG("local multiplayer game started");
   if (standard_init())
     {
+      slow_down_allowed=true;
+
       dispatcher=new U61_LocalDispatcher();
 
       num0=get_local_player(0);
@@ -622,6 +655,8 @@ void U61_Game::start_local_multiplayer()
             }
         }
     }
+
+  U61_Music::start();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -636,6 +671,8 @@ void U61_Game::start_network_new()
   U61_LOG_DEBUG("new network game started");
   if (standard_init())
     {
+      slow_down_allowed=false;
+
       d=new U61_ServerDispatcher();
       dispatcher=d;     
       
@@ -668,6 +705,8 @@ void U61_Game::start_network_new()
 	     &(player[U61_Layout::NB_PLAYERS_NET_LOCAL]));
 	}
     }
+
+  U61_Music::start();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -682,6 +721,8 @@ void U61_Game::start_network_join()
   
   if (standard_init())
     {
+      slow_down_allowed=false;
+
       d=new U61_ClientDispatcher();
       dispatcher=d;     
 
@@ -735,6 +776,7 @@ void U61_Game::do_network_join(char *script,
 	 &(player[U61_Layout::NB_PLAYERS_NET_LOCAL]));
     }
 
+  U61_Music::start();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -761,9 +803,19 @@ void U61_Game::stop_network()
  */
 void U61_Game::stop()
 {
+  int i;
+
+  for (i=0;i<U61_Layout::NB_PLAYERS_TOTAL;++i)
+    {
+      player[i].kill();
+    }
   reset_players();
   U61_Global::layout.reset();
   stop_network();
+  U61_Time::resume();
+
+  U61_Platform::close_score_file();
+
   U61_LOG_DEBUG("game stopped");
 }
 
@@ -783,10 +835,11 @@ bool U61_Game::standard_init()
 
   time_reset();
 
-  stop();
+  U61_Platform::open_score_file();
+  U61_Global::score.reset();
 
   ok=ok && U61_Global::config.load_script();
-    
+
   return ok;
 }
 
