@@ -138,8 +138,10 @@ class U61_Game
   enum {STATE_RUN,STATE_QUIT};
 
   int state;
+  bool slow_down_allowed;
 
-  static const int MAX_LOGIC_PER_DISPLAY=50;
+  static const int MAX_LOGIC_PER_DISPLAY=1000;
+  static const int LIMIT_LOGIC_PER_DISPLAY=100;
   static const int MENU_POLL_DELAY=33;
 
   int last_clanlib_time_polled;
