@@ -44,6 +44,7 @@
 #include "edit.h"
 #include "global.h"
 #include "savescriptmenu.h"
+#include "scoremenu.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -73,15 +74,16 @@ U61_JoinMenu::U61_JoinMenu(U61_Menu *parent)
 U61_Menu *U61_JoinMenu::validate()
 {
   U61_Menu *next_menu;
-  U61_Menu *save_menu;
 
   next_menu=this;
 
   switch (selection)
     {
     case 0:
-      save_menu=new U61_SaveScriptMenu(this);
-      next_menu=new U61_NonPausingMenu(new U61_NetworkMenu(save_menu));
+      next_menu=new U61_NonPausingMenu
+	(new U61_NetworkMenu
+	 (new U61_SaveScriptMenu
+	  (new U61_ScoreMenu(this))));
       U61_Global::game.start_network_join();
       break;
     }
