@@ -45,6 +45,7 @@
 #include "keychoose.h"
 #include "menuinput.h"
 #include "debug.h"
+#include "global.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -88,14 +89,7 @@ void U61_KeyChoose::update()
     }
   else
     {
-      if (key_map==NULL)
-        {
-	  U61_LOG_DEBUG("key_map KO");
-        }
-      else
-        {
-	  strcat(buffer,key_map->get_label(*value));
-        }
+      strcat(buffer,U61_Global::input_monitor.to_label(*value));
     }
   set_text(buffer);
 }
@@ -138,7 +132,7 @@ void U61_KeyChoose::select()
 {
   int start;
 
-  start=strlen(name);
+  start=strlen(name)+strlen(SEPARATOR);
 
   select_right(start);
 }
