@@ -79,8 +79,8 @@ U61_KeyMenu::U61_KeyMenu(U61_Menu *parent,
                                &(config->key_next_victim)));
     add_item(new U61_KeyChoose("Previous victim",
                                &(config->key_prev_victim)));
-    add_item(new U61_KeyChoose("Use antedote",
-                               &(config->key_use_antedote)));
+    add_item(new U61_KeyChoose("Use antidote",
+                               &(config->key_use_antidote)));
 
     select(0);
 }
