@@ -43,6 +43,7 @@
 #include "layout.h"
 
 #include "global.h"
+#include "utils.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -66,8 +67,7 @@ U61_Layout::U61_Layout()
  * frees the layout
  */ 
 U61_Layout::~U61_Layout()
-{
-    
+{    
 }
 
 /*--------------------------------------------------------------------------*/
@@ -186,7 +186,12 @@ void U61_Layout::init_multiplayer_4(U61_Player *p1,
 void U61_Layout::init_network_1(U61_Player *p1,
                                 U61_Player *net)
 {
-  init_multiplayer_1(p1);
+  reset();
+
+  items[4].init(p1,
+		(4*U61_Global::data.screen_w)/8,
+		U61_Global::data.screen_h/2,
+		U61_Data::SIZE_BIG);
 
   init_network_common(net);
 }
@@ -199,7 +204,16 @@ void U61_Layout::init_network_2(U61_Player *p1,
 				U61_Player *p2,
                                 U61_Player *net)
 {
-  init_multiplayer_2(p1,p2);
+  reset();
+
+  items[4].init(p1,
+		(3*U61_Global::data.screen_w)/8,
+		U61_Global::data.screen_h/2,
+		U61_Data::SIZE_BIG);
+  items[5].init(p2,
+		(5*U61_Global::data.screen_w)/8,
+		U61_Global::data.screen_h/2,
+		U61_Data::SIZE_BIG);
 
   init_network_common(net);
 }
@@ -210,35 +224,51 @@ void U61_Layout::init_network_2(U61_Player *p1,
  */
 void U61_Layout::init_network_common(U61_Player *net)
 {
-  items[2].init(net,
+  int i,slot1,slot2,temp;
+  int corres[]={0,1,2,3,4,5,6,7};
+
+  /*
+   * now we shuffle the network players so that they seem to appear
+   * randomly on the screen
+   */
+  for (i=0;i<SHUFFLE_COUNT;++i)
+    {
+      slot1=U61_Utils::random(8);
+      slot2=U61_Utils::random(8);
+      temp=corres[slot1];
+      corres[slot1]=corres[slot2];
+      corres[slot2]=temp;     
+    }
+
+  items[0].init(net+corres[0],
 		(1*U61_Global::data.screen_w)/16,
 		(1*U61_Global::data.screen_h)/4,
 		U61_Data::SIZE_SMALL);  
-  items[3].init(net+1,
+  items[1].init(net+corres[1],
 		(3*U61_Global::data.screen_w)/16,
 		(1*U61_Global::data.screen_h)/4,
 		U61_Data::SIZE_SMALL);  
-  items[4].init(net+2,
+  items[2].init(net+corres[2],
 		(1*U61_Global::data.screen_w)/16,
 		(3*U61_Global::data.screen_h)/4,
 		U61_Data::SIZE_SMALL);  
-  items[5].init(net+3,
+  items[3].init(net+corres[3],
 		(3*U61_Global::data.screen_w)/16,
 		(3*U61_Global::data.screen_h)/4,
 		U61_Data::SIZE_SMALL);  
-  items[6].init(net+4,
+  items[6].init(net+corres[4],
 		(13*U61_Global::data.screen_w)/16,
 		(1*U61_Global::data.screen_h)/4,
 		U61_Data::SIZE_SMALL);  
-  items[7].init(net+5,
+  items[7].init(net+corres[5],
 		(15*U61_Global::data.screen_w)/16,
 		(1*U61_Global::data.screen_h)/4,
 		U61_Data::SIZE_SMALL);  
-  items[8].init(net+6,
+  items[8].init(net+corres[6],
 		(13*U61_Global::data.screen_w)/16,
 		(3*U61_Global::data.screen_h)/4,
 		U61_Data::SIZE_SMALL);  
-  items[9].init(net+7,
+  items[9].init(net+corres[7],
 		(15*U61_Global::data.screen_w)/16,
 		(3*U61_Global::data.screen_h)/4,
 		U61_Data::SIZE_SMALL);  
@@ -264,6 +294,131 @@ void U61_Layout::draw()
     }    
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * checks if the id of the player is correct and returns the next if not 
+ */
+int U61_Layout::check_player_id(int old_id,int own_id)
+{
+  int result=own_id;
+  int i;
+  int old=-1;
+
+  /*
+   * we try and find where's the player with the id given
+   */
+  for (i=0;i<NB_PLAYERS_TOTAL;++i)
+    {
+      if (items[i].get_player_id()==old_id)
+	{
+	  old=i;
+	}
+    }
+
+  if (old<0 || old_id==own_id)
+    {
+      result=get_next_player_id(old_id,own_id);
+    }
+  else
+    {
+      result=old_id;
+    }  
+
+  return result;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the id of the previous player 
+ */
+int U61_Layout::get_prev_player_id(int old_id,int own_id)
+{
+  int result=own_id;
+  int i,j;
+  int old=-1;
+  int new_id=-1;
+
+  /*
+   * we try and find where's the player with the id given
+   */
+  for (i=0;i<NB_PLAYERS_TOTAL;++i)
+    {
+      if (items[i].get_player_id()==old_id)
+	{
+	  old=i;
+	}
+    }
+
+  if (old>=0)
+    {
+      /*
+       * now we find the closest previous player that exists and get his id
+       */
+      j=old-1;
+      for (i=0;i<NB_PLAYERS_TOTAL && result==own_id;++i)
+        {
+          if (j<0)
+	    {
+	      j+=NB_PLAYERS_TOTAL;
+	    }
+          if (items[j].is_player_available()
+	      && (new_id=items[j].get_player_id())!=own_id)
+	    {
+	      result=new_id;
+	    }
+          j--;
+        }
+    }
+
+  return result;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the id of the next player 
+ */
+int U61_Layout::get_next_player_id(int old_id,int own_id)
+{
+  int result=own_id;
+  int i,j;
+  int old=-1;
+  int new_id=-1;
+
+  /*
+   * we try and find where's the player with the id given
+   */
+  for (i=0;i<NB_PLAYERS_TOTAL;++i)
+    {
+      if (items[i].get_player_id()==old_id)
+	{
+	  old=i;
+	}
+    }
+
+  if (old>=0)
+    {
+      /*
+       * now we find the closest next player that exists and get his id
+       */
+      j=old+1;
+      for (i=0;i<NB_PLAYERS_TOTAL && result==own_id;++i)
+        {
+          if (j>=NB_PLAYERS_TOTAL)
+	    {
+	      j-=NB_PLAYERS_TOTAL;
+	    }
+          if (items[j].is_player_available()
+	      && (new_id=items[j].get_player_id())!=own_id)
+	    {
+	      result=new_id;
+	    }
+          j++;
+        }
+    }
+
+  return result;
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * returns true if one of the backgrounds has changed
