@@ -63,17 +63,17 @@
  */ 
 const int U61_Map::speeds[MAX_SYSTEM_SPEED+1]=
 {
-  1,    2,  5, 10, 20, 30, 40, 50, 60, 70, 80,
-  84, 88, 92, 96,100,104,108,112,116,120,
+  1,  2,  5,  10, 20, 30, 40, 50, 60, 70, 80,
+  84, 88, 92, 96, 100,104,108,112,116,120,
   124,128,132,136,140,144,148,152,156,160,
   164,168,172,176,180,184,188,192,196,200,
   210,220,240,260,280,300,350,400,450,500
 };
 const int U61_Map::accels[MAX_SYSTEM_ACCEL+1]=
 {
-  0,  5, 10, 15, 20, 25,
-  30, 40, 50, 70,100,
-  130,160,190,220,250
+  0,  10, 20, 30, 40, 50,
+  60, 80, 100,140,200,
+  260,320,380,440,500
 };
 
 /*---------------------------------------------------------------------------
@@ -154,11 +154,10 @@ void U61_Map::begin()
   curse_asked=false;
   curse_state=false;
   nb_antidote=0;
-  if (score>best_score)
-    {
-      best_score=score;
-    }
   score=0;
+  curse_sent=0;
+  curse_received=0;
+  start_time=0;
   for (i=0;i<NB_GLOBAL;++i)
     {
       global_val[i]=0;
@@ -197,9 +196,7 @@ void U61_Map::reset()
   target_id=player_id;
   map_time=0;
   active=false;
-  best_score=0;
   score=0;
-  games=0; 
   silent=false;
 
   begin();
@@ -334,11 +331,40 @@ int U61_Map::get_score()
 
 /*--------------------------------------------------------------------------*/
 /*
- * gets the best score associated to the map
+ * gets the time of the last game
  */
-int U61_Map::get_best_score()
+int U61_Map::get_elapsed_time()
 {
-  return best_score;
+  int elapsed;
+
+  if (map_time==0 || start_time==0 || map_time<start_time)
+    {
+      elapsed=0;
+    }
+  else
+    {
+      elapsed=map_time-start_time;
+    }
+
+  return elapsed;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * gets the number of curses sent during the last game
+ */
+int U61_Map::get_curse_sent()
+{
+  return curse_sent;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * gets the number of curses received during the last game
+ */
+int U61_Map::get_curse_received()
+{
+  return curse_received;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -363,15 +389,6 @@ int U61_Map::get_time()
   return map_time;
 }
 
-/*--------------------------------------------------------------------------*/
-/*
- * gets the number of games associated to the map
- */
-int U61_Map::get_nb_games()
-{
-  return games;
-}
-
 /*--------------------------------------------------------------------------*/
 /*
  * returns a number which is used by the lua match function
@@ -661,6 +678,7 @@ void U61_Map::send_curse(int curse_id)
     {
       U61_LOG_DEBUG("Sending curse "<<curse_id);
 
+      curse_sent++;
       evt.code=U61_Event::REQUEST_CURSE;
       evt.par=curse_id;
       /*
@@ -770,6 +788,10 @@ void U61_Map::handle_event(U61_Event *event)
 {
   if (active)
     {
+      if (start_time==0)
+	{
+	  start_time=map_time;
+	}
       if (int(event->time)<map_time)
         {
 	  U61_LOG_DEBUG("Inconsitency in event dates detected with event "<<*event<<" and map_time="<<map_time);
@@ -989,15 +1011,8 @@ void U61_Map::draw(int x,int y, int size, bool anti)
 
   if (active)
     {
-      x_square_offset=
-	(U61_Global::data.map_w[size]
-	 -WIDTH*U61_Global::data.square_w[size])/2;
-      y_square_offset=
-	(U61_Global::data.map_h[size]
-	 -HEIGHT*U61_Global::data.square_h[size])/2;
-        
-      x_square_offset+=x;
-      y_square_offset+=y;
+      x_square_offset=U61_Global::data.offset_map_x[size]+x;
+      y_square_offset=U61_Global::data.offset_map_y[size]+y;
 
       U61_Global::data.map[background][size]->put_screen(x,y);
 
@@ -1785,6 +1800,7 @@ void U61_Map::do_curse(U61_Event evt)
     }
   else
     {
+      curse_received++;
       evt.par-=MAX_CURSE_ID;
       U61_LOG_DEBUG("Do remote curse "<<evt);
       U61_Script::do_curse(this,&block,evt.par,true);
@@ -1899,6 +1915,7 @@ void U61_Map::check_block()
   int min_x,max_x;
   U61_Block test;
   bool ok;
+  bool moved_sideways=false;
 
   n=block.get_nb_items();
 
@@ -1967,6 +1984,7 @@ void U61_Map::check_block()
 	      /*
 	       * The block is OK after it has been moved on the left
 	       */
+	      moved_sideways=true;
 	      block=test;
 	      ok=true;
 	    }
@@ -1978,6 +1996,7 @@ void U61_Map::check_block()
 		  /*
 		   * The block is OK after it has been moved on the right
 		   */
+		  moved_sideways=true;
 		  block=test;
 		  ok=true;
 		}
@@ -1987,11 +2006,17 @@ void U61_Map::check_block()
 	{
 	  /*
 	   * The block is OK after it has been moved up.
-	   * We move it up of one more square to give the player a chance to place
-	   * it, otherwise it would be really unfair. However, it's still hard
-	   * to place it correctly, but it's the game...
+	   * We move it up of one more square to give the player a chance to
+	   * place it, otherwise it would be really unfair. However, it's
+	   * still hard to place it correctly, but it's the game...
+	   * Note that this is only done if we had needed to move the block
+	   * sideways, otherwise one gets some strange buggy boucing effects
+	   * when the time callback moves the block down for instance.
 	   */
-	  block.set_y(block.get_y()-1);
+	  if (moved_sideways)
+	    {
+	      block.set_y(block.get_y()-1);
+	    }
 	  ok=true;
 	}
     }
