@@ -84,10 +84,11 @@ public:
 
     void set_score(int s);
     int get_score();
-    int get_best_score();
     void add_score(int s);
+    int get_elapsed_time();
+    int get_curse_sent();
+    int get_curse_received();
     int get_time();
-    int get_nb_games();
     int get_match_count();
     void set_global(int i,int glob);
     int get_global(int i);
@@ -111,6 +112,8 @@ public:
     void send_curse(int par);
     char *get_curse_name();
 
+    bool is_block_ok(U61_Block *test);
+
     int get_target_id();
 
     void draw(int x,int y, 
@@ -149,7 +152,7 @@ public:
     static const int NB_GLOBAL=1000;
     static const int MAX_CURSE_ID=1000;
     static const int SPEED_SCALE=1000;
-    static const int ACCEL_SCALE=100000;
+    static const int ACCEL_SCALE=1000000;
     static const int TIME_CALLBACK_DELAY=10;
     static const int CHECK_TARGET_DELAY=100;
     static const int CHECK_CURSE_DELAY=100;
@@ -190,8 +193,9 @@ protected:
     int base_speed;
     int base_accel;
     int score;
-    int best_score;
-    int games;
+    int curse_sent;
+    int curse_received;
+    int start_time;
     int match_count;
     bool anticipation_state;
     bool preview_state;
@@ -225,7 +229,6 @@ protected:
     void use_antidote();
 
     bool is_block_active();
-    bool is_block_ok(U61_Block *test);
   
     void new_block(int shape);
     void stabilize_block();
