@@ -95,6 +95,7 @@ U61_Menu::U61_Menu(U61_Menu *parent,char *top)
   parent_menu=parent;
   top_message=top;
   message_active=true;
+  drawn_once=false;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -221,20 +222,88 @@ void U61_Menu::draw()
   int nb_item;
   int last_item_height2;
   int item_height;
+  int max_disp_item;
+  int first_disp_item;
+  int real_disp_item;
+
+  if (!drawn_once)
+    {
+      before_first_draw();
+      drawn_once=true;
+    }
 
   nb_item=items.size();
+  /*
+   * We calculate the number of displayable items. To amke the calculus,
+   * we assume that the average height of a menu item is the height of the
+   * font. Then we choose the highest odd number so that there's still room
+   * on the screen to draw the top and bottom messages, plus a gap between
+   * those messages and the real menu.
+   */
+  max_disp_item=(U61_Global::data.screen_h
+		 /U61_Global::data.font_menu->get_height()
+		 )-3;
+  if (!(max_disp_item%2))
+    {
+      ++max_disp_item;
+    }
+
+  if (nb_item<=max_disp_item)
+    {
+      /*
+       * This is the easy case, we have enough room to display all the items
+       * so the first item is number 0, and there are as many displayed items
+       * as there are items in the menu.
+       */
+      first_disp_item=0;
+      real_disp_item=nb_item;
+    }
+  else
+    {
+      /*
+       * Now this is the worst case, for all the items can't fit in a screen.
+       * We have to choose which items we display. The algorithm assumes that
+       * the maximum number of displayable items (max_nb_item) is odd.
+       */
+      real_disp_item=max_disp_item;
+      /*
+       * By default we suppose we are at the beginning
+       */
+      first_disp_item=0;
+      /*
+       * Now if we are too far in the menu, the selected item we'll be
+       * in the center of the screen
+       */
+      if (selection>max_disp_item/2)
+	{
+	  first_disp_item=selection-max_disp_item/2;
+	}
+      /*
+       * If we are at the end of the menu, always display the last item
+       * at the bottom of the screen
+       */
+      if (selection>nb_item-max_disp_item/2-1)
+	{
+	  first_disp_item=nb_item-max_disp_item;
+	}
+    }
 
   if (shaded)
     {
       U61_Global::data.shade->put_screen(0,0);
     }
 
+  /*
+   * The first step is to calculate all the y coordinates for all the
+   * menus. Then we''l decide which ones we want to display and where,
+   * in case there are too many of them
+   */
   y=U61_Global::data.screen_h/2;
 
-  y-=get_height()/2;
+  y-=get_height(first_disp_item,real_disp_item)/2;
   last_item_height2=0;
 
-  for (i=0;i<nb_item;++i)
+  for (i=first_disp_item;i<first_disp_item+real_disp_item;++i)
     {
       item_height=items[i]->get_height();
 
@@ -243,6 +312,11 @@ void U61_Menu::draw()
       last_item_height2=item_height-item_height/2;
     }
 
+  /*
+   * Now we print the top and bottom messages, top message contains the
+   * name of the menu and botton message is a scrolling general information
+   * message
+   */
   if (message_active)
     {
       draw_top_message();
@@ -250,18 +324,31 @@ void U61_Menu::draw()
     }
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * This is a weird hack for menus such as the score menus. Those menus are
+ * created at a time when the information they must display is not ready
+ * yet. Therefore, the before_first_draw is a special callback which is
+ * called once before the first draw. It will never be called after.
+ * So typically, in a score menu, this is where the menu items are added.
+ */
+void U61_Menu::before_first_draw()
+{
+
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * returns the height of the menu
  */
-int U61_Menu::get_height()
+int U61_Menu::get_height(int first,int nb)
 {
   int i;
   int nb_item;
   int height=0;
 
   nb_item=items.size();
-  for (i=0;i<nb_item;++i)
+  for (i=first;i<first+nb;++i)
     {
       height+=items[i]->get_height();
     }
@@ -272,14 +359,14 @@ int U61_Menu::get_height()
 /*
  * returns the width of the menu
  */
-int U61_Menu::get_width()
+int U61_Menu::get_width(int first,int nb)
 {
   int i;
   int nb_item;
   int width=0;
 
   nb_item=items.size();
-  for (i=0;i<nb_item;++i)
+  for (i=first;i<first+nb;++i)
     {
       width=max(items[i]->get_width(),width);
     }
