@@ -60,11 +60,12 @@ class U61_Menu
   virtual U61_Menu *validate();
   virtual U61_Menu *back();
   void draw();
+  virtual void before_first_draw();
   void select(int num_item);
   virtual void select_up();
   virtual void select_down();
-  int get_height();
-  int get_width();
+  int get_height(int first, int nb);
+  int get_width(int first, int nb);
   void add_item(U61_MenuItem *item);
   U61_Menu *get_parent();
 
@@ -76,6 +77,7 @@ class U61_Menu
   U61_Menu *parent_menu;    
   int selection;
   char *top_message;
+  bool drawn_once;
 
   static bool shaded;
   bool message_active;
@@ -93,3 +95,4 @@ class U61_Menu
 };
 
 #endif
+
