@@ -43,6 +43,7 @@
 #include "networkmenu.h"
 #include "nonpausingmenu.h"
 #include "playermenu.h"
+#include "graphicsmenu.h"
 #include "soundmenu.h"
 #include "button.h"
 #include "time.h"
@@ -70,6 +71,7 @@ U61_NetworkMenu::U61_NetworkMenu(U61_Menu *parent)
   add_item(new U61_Button("Player 2 options"));
   add_item(new U61_Button("Player 3 options"));
   add_item(new U61_Button("Player 4 options"));
+  add_item(new U61_Button("Graphics"));
   add_item(new U61_Button("Sound"));
   select(0);
 }
@@ -106,6 +108,9 @@ U61_Menu *U61_NetworkMenu::validate()
       next_menu=new U61_PlayerMenu(this, &(U61_Global::config.player[3]));
       break;
     case 6:
+      next_menu=new U61_GraphicsMenu(this, &(U61_Global::config));
+      break;
+    case 7:
       next_menu=new U61_SoundMenu(this, &(U61_Global::config));
       break;
     }
