@@ -73,6 +73,10 @@ class U61_Platform
 
   static void exec(char *file);
 
+  static void open_score_file();
+  static void close_score_file();
+  static void dump_score(char *text);
+
   static void open_log_files();
   static void close_log_files();
   static void log_to_error_file(char *text);
