@@ -54,6 +54,13 @@
  variants
  ---------------------------------------------------------------------------*/
 
+/*--------------------------------------------------------------------------*/
+/*
+ * This file is used to dump the scores and keep a trace of what's happening.
+ * On UNIX it is located in ~/.u61/score.txt
+ */
+static FILE *score_file=NULL;
+
 /*--------------------------------------------------------------------------*/
 /*
  * The file is used to log the debug messages, it is stored in ~/.u61 and
@@ -412,6 +419,71 @@ void U61_Platform::exec(char *file)
   exit(1);
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * Opens the score file, on UNIX, it is ~/.u61/score.txt
+ */
+void U61_Platform::open_score_file()
+{
+  char buffer[U61_STRING_SIZE];
+
+  if (score_file==NULL)
+    {
+      strcpy (buffer,get_user_path());
+      strcat(buffer,"score.txt");
+
+      score_file=fopen(buffer,"a");
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Closes the score file, on UNIX, it is ~/.u61/score.txt
+ */
+void U61_Platform::close_score_file()
+{
+  if (score_file!=NULL)
+    {
+      fclose(score_file);
+    }
+
+  score_file=NULL;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Logs an error message with syslog and in the debug log if needed
+ */
+void U61_Platform::dump_score(char *text)
+{
+  time_t curtime;
+  struct tm *loctime;
+  char buffer_date[U61_STRING_SIZE];
+
+  if (score_file!=NULL)
+    {     
+      /*
+       * Get the current time.
+       */
+      curtime = time (NULL);
+     
+      /*
+       * Convert it to local time representation.
+       */
+      loctime = localtime (&curtime);
+     
+      sprintf(buffer_date,asctime(loctime));
+      /*
+       * We get rid of the trailing '\n'
+       */
+      if (strlen(buffer_date)>=24)
+	{
+	  buffer_date[24]=0;
+	}
+      fprintf(score_file,"%-24s ; %s\n",buffer_date,text);
+    }
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * Opens all the log files, on UNIX, this concerns only the debug log
@@ -424,10 +496,13 @@ void U61_Platform::open_log_files()
 #ifdef DEBUG
   char buffer[U61_STRING_SIZE];
 
-  strcpy (buffer,get_user_path());
-  strcat(buffer,"debug.log");
+  if (debug_file==NULL)
+    {
+      strcpy (buffer,get_user_path());
+      strcat(buffer,"debug.log");
 
-  debug_file=fopen(buffer,"w");
+      debug_file=fopen(buffer,"w");
+    }
 #endif
 }
 
