@@ -85,7 +85,6 @@ class U61_Player
   char *get_name();
   int get_target_id();
   int get_score();
-  int get_best_score();
   U61_Block get_next_block();
   int get_nb_curse();
   int get_nb_antidote();
@@ -128,6 +127,7 @@ class U61_Player
   void stop();
 
   void copy_sure_to_last();
+  void register_score();
 };
 
 #endif
