@@ -1458,6 +1458,19 @@ static void delete_antidote()
     }
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * this function is accessible from lua script 
+ * it checks if the current block has a correct position
+ */
+static void is_block_ok()
+{
+  if (current_map!=NULL && map_read && current_block!=NULL && block_read)
+    {
+      return_lua_int(current_map->is_block_ok(current_block));
+    }
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * registers all C functions that can be used from Lua
@@ -1510,6 +1523,7 @@ void U61_Script::record_all()
   CL_Lua::record(C_GET_NB_ANTIDOTES,get_nb_antidotes);
   CL_Lua::record(C_ADD_ANTIDOTE,add_antidote);
   CL_Lua::record(C_DELETE_ANTIDOTE,delete_antidote);
+  CL_Lua::record(C_IS_BLOCK_OK,is_block_ok);
 }
 
 
