@@ -45,12 +45,6 @@
  variants
  ---------------------------------------------------------------------------*/
 
-/*--------------------------------------------------------------------------*/
-/*
- * contains the name of the log file
- */
-bool U61_Sound::state=true;
-
 /*---------------------------------------------------------------------------
  functions
  ---------------------------------------------------------------------------*/
@@ -61,9 +55,13 @@ bool U61_Sound::state=true;
  */
 void U61_Sound::play(CL_SoundBuffer *sound)
 {
-    if (state && sound!=NULL)
+  int volume;
+
+  volume=U61_Global::config.sound_volume;
+  if (volume>0 && sound!=NULL)
     {
-        sound->play();
+      sound->set_volume(2.0*((float) volume)/((float) VOLUME_MAX));
+      sound->play();
     }
 }
 
@@ -73,7 +71,7 @@ void U61_Sound::play(CL_SoundBuffer *sound)
  */
 void U61_Sound::play_game_start()
 {
-    play(U61_Global::data.sound_game_start);
+  play(U61_Global::data.sound_game_start);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -82,7 +80,7 @@ void U61_Sound::play_game_start()
  */
 void U61_Sound::play_menu_move()
 {
-    play(U61_Global::data.sound_menu_move);
+  play(U61_Global::data.sound_menu_move);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -91,7 +89,7 @@ void U61_Sound::play_menu_move()
  */
 void U61_Sound::play_menu_validate()
 {
-    play(U61_Global::data.sound_menu_validate);
+  play(U61_Global::data.sound_menu_validate);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -100,7 +98,7 @@ void U61_Sound::play_menu_validate()
  */
 void U61_Sound::play_block_touch()
 {
-    play(U61_Global::data.sound_block_touch);
+  play(U61_Global::data.sound_block_touch);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -109,7 +107,7 @@ void U61_Sound::play_block_touch()
  */
 void U61_Sound::play_block_pattern()
 {
-    play(U61_Global::data.sound_block_pattern);
+  play(U61_Global::data.sound_block_pattern);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -118,7 +116,7 @@ void U61_Sound::play_block_pattern()
  */
 void U61_Sound::play_player_start()
 {
-    play(U61_Global::data.sound_player_start);
+  play(U61_Global::data.sound_player_start);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -127,7 +125,7 @@ void U61_Sound::play_player_start()
  */
 void U61_Sound::play_curse_receive()
 {
-    play(U61_Global::data.sound_curse_receive);
+  play(U61_Global::data.sound_curse_receive);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -136,6 +134,6 @@ void U61_Sound::play_curse_receive()
  */
 void U61_Sound::play_player_loose()
 {
-    play(U61_Global::data.sound_player_loose);
+  play(U61_Global::data.sound_player_loose);
 }
 
