@@ -49,21 +49,19 @@
 
 class U61_Sound
 {
-public:
-    static void enable();
-    static void disable();
+ public:
+  static void play_game_start();
+  static void play_menu_move();
+  static void play_menu_validate();
+  static void play_block_touch();
+  static void play_block_pattern();
+  static void play_player_start();
+  static void play_curse_receive();
+  static void play_player_loose();
 
-    static void play_game_start();
-    static void play_menu_move();
-    static void play_menu_validate();
-    static void play_block_touch();
-    static void play_block_pattern();
-    static void play_player_start();
-    static void play_curse_receive();
-    static void play_player_loose();
-protected:
-    static void play(CL_SoundBuffer *sound);
-    static bool state;    
+  static const int VOLUME_MAX=10;
+ protected:
+  static void play(CL_SoundBuffer *sound);
 };
 
 #endif
