@@ -73,7 +73,7 @@ class U61_Square
   static bool should_blink();
 
   void draw(int x,int y, int size=U61_Data::SIZE_BIG);
-  void draw_prevision(int x,int y, int size=U61_Data::SIZE_BIG);
+  void draw_anticipation(int x,int y, int size=U61_Data::SIZE_BIG);
   void draw_curse(int x,int y, int size=U61_Data::SIZE_BIG);
 
   void begin_explosion();
