@@ -51,10 +51,10 @@
 class U61_Time
 {
 public:
-    static void reset(int time=0);
-    static int for_event();
-    static int for_logic();
-    static int for_effect();
+    static void reset(int unsigned time=0);
+    static unsigned int for_event();
+    static unsigned int for_logic();
+    static unsigned int for_effect();
     static void alter(int delta);   
     static void speed_up();   
     static void slow_down();   
@@ -72,11 +72,11 @@ protected:
     static int reset_offset;
     static int alter_offset;
     static int pause_offset;
-    static int start_pause_time;
+    static unsigned int start_pause_time;
     static bool paused;
-    static int last_for_event;
-    static int last_for_logic;    
-    static int last_for_display;
+    static unsigned int last_for_event;
+    static unsigned int last_for_logic;    
+    static unsigned int last_for_display;
 
     static const int TIME_UNIT=10;
     static const int IDLE_DELAY=5;
