@@ -122,9 +122,9 @@ bool U61_Toggle::action(int key)
 
     switch (key)
     {
-    case U61_MenuInput::KEY_LEFT:
-    case U61_MenuInput::KEY_RIGHT:
-    case U61_MenuInput::KEY_ENTER:
+    case CL_KEY_LEFT:
+    case CL_KEY_RIGHT:
+    case CL_KEY_ENTER:
         changed=true;
         toggle();
         break;
